=======
tsinfer
=======

Tsinfer is a method to infer a succinct tree sequence from genetic variation
data.

Please see the `documentation <https://tsinfer.readthedocs.org/en/stable/>`_
for further details.

See `here <https://tsinfer.readthedocs.org/en/stable/installation.html>`_ for
installation instructions.
